#!/usr/bin/env python
#
# Author: Thamme Gowda [tg (at) isi (dot) edu] 
# Created: 1/31/19
from rtg.module import Model
from abc import ABCMeta, ABC
"""
Stuff related to Language Model
"""